@@ -1,8 +1,9 @@
+import time
 import httpx
 import jinja2
 import pkgutil
 from lxml import etree
-from typing import Tuple
+from typing import Tuple, Union
 
 from nonebot_plugin_htmlrender import html_to_pic
 
@@ -15,6 +16,7 @@ def retry(func):
             except:
                 continue
         raise Exception('网络错误')
+
     return wrapper
 
 
@@ -43,20 +45,26 @@ async def get_shindan_title(id: int) -> str:
         return ''
 
 
-async def make_shindan(id: str, name: str) -> bytes:
+async def make_shindan(id: str, name: str, mode='image') -> Union[str, bytes]:
     url = f'https://shindanmaker.com/{id}'
+    seed = time.strftime("%y%m%d", time.localtime())
     async with httpx.AsyncClient() as client:
         resp = await get(client, url)
         token = parse_token(resp.text)
-        payload = {
-            '_token': token,
-            'shindanName': name,
-            'hiddenName': '名無しのR'
-        }
+        payload = {'_token': token, 'shindanName': name + seed, 'hiddenName': '名無しのR'}
         resp = await post(client, url, json=payload)
-    html, has_chart = await render_html(resp.text)
-    return await html_to_pic(html, wait=2000 if has_chart else 0,
-                             viewport={"width": 800, "height": 100})
+
+    content = resp.text
+    if mode == 'image':
+        html, has_chart = await render_html(content)
+        html = html.replace(name + seed, name)
+        return await html_to_pic(
+            html, wait=2000 if has_chart else 0, viewport={"width": 800, "height": 100}
+        )
+    else:
+        result = parse_result(content)
+        result = result.replace(name + seed, name)
+        return result
 
 
 def parse_title(content: str) -> str:
@@ -75,6 +83,15 @@ def parse_token(content: str) -> str:
         raise Exception('网站解析错误')
 
 
+def parse_result(content: str) -> str:
+    try:
+        dom = etree.HTML(content)
+        result = dom.xpath("//span[@id='shindanResult']")[0]
+        return result.xpath('string(.)').strip()
+    except:
+        raise Exception('网站解析错误')
+
+
 def load_file(name: str) -> str:
     return pkgutil.get_data(__name__, f"templates/{name}").decode()
 
@@ -94,17 +111,18 @@ async def render_html(content: str) -> Tuple[str, bool]:
     try:
         dom = etree.HTML(content)
         result_js = dom.xpath("//script[contains(text(), 'saveResult')]")[0]
-        title = dom.xpath(
-            "//div[contains(@class, 'shindanTitleDescBlock')]")[0]
+        title = dom.xpath("//div[contains(@class, 'shindanTitleDescBlock')]")[0]
         result = dom.xpath("//div[@id='shindanResultBlock']")[0]
         has_chart = dom.xpath("//script[contains(@src, 'chart.js')]")
     except:
         raise Exception('网站解析错误')
 
-    html = await shindan_tpl.render_async(app_css=app_css,
-                                          result_js=to_string(result_js),
-                                          app_js=app_js,
-                                          chart_js=chart_js if has_chart else '',
-                                          title=to_string(title),
-                                          result=to_string(result))
+    html = await shindan_tpl.render_async(
+        app_css=app_css,
+        result_js=to_string(result_js),
+        app_js=app_js,
+        chart_js=chart_js if has_chart else '',
+        title=to_string(title),
+        result=to_string(result),
+    )
     return html, has_chart
